@@ -1,16 +1,14 @@
 import re
 import boto3
 from botocore.exceptions import ClientError
-from botocore.config import Config
-from botocore import session
 
 
 def name_validator(text):
     return len(text) > 0
 
 
-def instance_type_validator(text, region, az):
-    response = session.get_session().create_client('ec2', config=Config(region_name=region)) \
+def instance_type_validator(text, session: boto3.Session, az):
+    response = session.client('ec2') \
         .describe_instance_type_offerings(
         LocationType='availability-zone',
         Filters=[
@@ -26,13 +24,14 @@ def port_validator(text):
     return re.match(pattern=r'^[0-9]{1,5}$', string=text)
 
 
-def stack_name_validator(text, region):
+def stack_name_validator(text, region, profile):
     if not len(text):
         return False
 
     else:
         try:
-            boto3.client('cloudformation', config=Config(region_name=region)).describe_stacks(StackName=text)
+            boto3.Session(profile_name=profile, region_name=region).client('cloudformation').describe_stacks(
+                StackName=text)
 
         except ClientError:  # stack doest
             return True
